# -*- coding: utf-8 -*-

#####################
## Command Sequence of Data Reduction
## 2010.11.10 ver 0.2 use GetHistogramOfEnergyTransfer
## 2010.05.18 ver 0.1
#####################

# special reserved word for commands history
from __future__ import print_function
HISTORY = None
# reserved words for return value in this.
DAT = None

import Manyo as mm
import Manyo.Utsusemi as mu
import utsusemi.ana.Reduction.BaseCommandsInEla as BaseCom
import utsusemi.DNA.ana.Reduction.BaseCommandsDNA as BaseComDNA
import re
import math
import datetime
import os
inst_code = mu.UtsusemiEnvGetInstCode()
if inst_code=="AMR":
    Def_NumOfPixel=120
    Def_L1=30.0
    Def_L2=4.0
    Def_dS=25.4*25.0
elif inst_code:
    Def_NumOfPixel=100
    Def_L1=18.03
    Def_L2=2.50
    Def_dS=25.4*19.0
elif inst_code:
    Def_NumOfPixel=100
    Def_L1=18.03
    Def_L2=2.50
    Def_dS=25.4*19.0
else:
    Def_NumOfPixel=100
    Def_L1=18.03
    Def_L2=2.50
    Def_dS=25.4*19.0
########################################
def CopyData(runno=10):
    """
    Copy EventData file from DAQ0 or DAQ1 into /data/SIK
    @param runno (int) First Run No of a measurement to be copied
    @retval None
    """
    BaseCom.CopyData(runno)

########################################
def GetDataOfWhite(runNo=197,startTOF=-1,endTOF=-1,binTOF=-1,MaskFile="mask.txt",NormFactor=1000000.0):
    """
    Load EventData and convert to histogram using corrections as below:
    - GetHistogram(runNo,startTOF=-1,endTOF=-1,binTOF=-1,startPSD=-1,endPSD=-1,pixelNo=100)
    - NormByBeamCurrent
    - DoMask
    - SolidAngleCorrection
    @param runNo      (int)    Run Number
    @param MaskFile   (string) file name for masking
    @param NormFactor (double) normalize factor data*factor/beamCurrent. if 0, do nothing.
    @retval DAT     (ElementContainerMatrix)
    """
    startPSD=-1
    endPSD=-1
    pixelNo=Def_NumOfPixel
    dat = BaseCom.GetHistogram(runNo,0,startTOF,endTOF,binTOF,startPSD,endPSD,pixelNo)
    if NormFactor!=0:
        BaseCom.NormByBeamCurrent(dat, NormFactor)
    BaseCom.DoMask(dat,MaskFile)
    BaseCom.SolidAngleCorrection(dat)

    return dat

#########################################
def GetDataOfMonochroEi(runNo=-1,Ei=0.0,Resolution=0.5,deltaE=0.0,L1=18.03,MaskFile="mask.txt",NormFactor=1000000.0):
    """
    Load EventData and convert to histogram using corrections as below:
    - GetHistogramBydE(runNo,Ei,Resolution=round(deltaE/Ei)/10,t0shift=0.0,L1,L2=2.5,NumOfPixel=100)
    - NormByBeamCurrent(DAT,NormFactor)
    - DoMask(DAT)
    - TofToEnergyTransfer(DAT,Ei,L1,t0shift=0.0,deltaE,EminRate=0.9,EmaxRate=0.9)
    - SolidAngleCorrection(DAT)
    - kikfCorrection(DAT)
    @param runNo    (int) Run Number
    @param Ei       (double) Incident Energy
    @param Resolution (double) Energy Resolution for tof binnings at Elastic Peak [%]
    @param deltaE   (double) Delta Energy Transfer [meV]
    @param L1       (double)  Distance between moderator to sample [m]
    @param MaskFile (string) file name for masking
    @param NormFactor (double) normalize factor data*factor/beamCurrent. if 0, do nothing.
    @retval DAT     ElementCotainerMatix as result
    """
    if (Ei<=0.0) or (deltaE<=0.0):
        raise UserWarning("ParameterError")
    
    #Resolution = round(deltaE/Ei)/10.0
    t0shift = 0.0
    L2 = Def_L2
    numOfPixel = Def_NumOfPixel
    EminRate = 0.9
    EmaxRate = 0.9
    
    dat = BaseCom.GetHistogramBydE(runNo,Ei,Resolution,t0shift,L1,L2,numOfPixel)
    if NormFactor!=0:
        BaseCom.NormByBeamCurrent(dat, NormFactor)
    BaseCom.DoMask(dat,MaskFile)
    BaseCom.SolidAngleCorrection(dat)
    BaseCom.TofToEnergyTransfer(dat,Ei,L1,t0shift,deltaE,EminRate,EmaxRate)
    BaseCom.KiKfCorrection(dat)

    return dat

#########################################
def GetDataOfMonochroEi2(runNo=-1,Ei=0.0,deltaE=0.0,Emin=0.0,Emax=0.0,MaskFile="mask.txt",NormFactor=1000000.0):
    """
    Load EventData and convert to histogram using corrections as below:
    - GetHistogramOfEnergyTransfer(runNo,Ei,dHW,hw_min,hw_max,startTime,endTime)
    - NormByBeamCurrent(DAT,NormFactor)
    - DoMask(DAT)
    - SolidAngleCorrection(DAT)
    - kikfCorrection(DAT)
    @param runNo    (int) Run Number
    @param Ei       (double) Incident Energy [meV]
    @param deltaE   (double) Delta Energy Transfer [meV]
    @param Emin     (double) minimum of Energy Transfer [meV]
    @param Emax     (double) maximum of Energy Transfer [meV]
    @param MaskFile (string) file name for masking
    @param NormFactor (double) normalize factor data*factor/beamCurrent. if 0, do nothing.
    @retval DAT     ElementCotainerMatix as result
    """
    if (Ei<=0.0) or (deltaE<=0.0):
        raise UserWarning("ParameterError")
        
    dat = BaseCom.GetHistogramOfEnergyTransfer(runNo,Ei,deltaE,Emin,Emax)
    if runNo!=0: ## [inamura 101115]
        if NormFactor!=0:
            BaseCom.NormByBeamCurrent(dat, NormFactor)
        BaseCom.DoMask(dat,MaskFile)
        BaseCom.SolidAngleCorrection(dat)
        BaseCom.KiKfCorrection(dat)

    return dat

##########################################
def ToPowder(dat=DAT,startQ=-1.0,endQ=-1.0,deltaQ=0.1):
    """
    Convert data from crystal to powder

    @param dat    (ElementContaienrMatrix)
    @param startQ (double) Q value of range; if minus, auto calculated
    @param endQ   (double) Q value of range; if minus, auto calculated
    @param deltaQ (double) binning of Q
    @retval ECM   (ElementContainerMatrix)
    """

    return BaseCom.ToPowder(dat,startQ,endQ,deltaQ)

#########################################

def GetDataOfDNA(runNo=314,HwParam=" ",LambParam=" ",QParam=" ",TimeParam=" ",initFile="GetQEDataOfDNA.ini",outputData="QE",fileTag="_"):
    """
    Load EventData and convert to QE map
    - GetHistogramHW(runNo,dHW,hw_min,hw_max,tof_offset,startTime,endTime)
    - DoMask(DAT)
    - ILambdaCorrDNA(dat,ec)
    - SolidAngleCorrDNA(dat)
    - CreateQEMap(dat,startQ,endQ,deltaQ)

    @param runNo        (int) Run Number
    @param HwParam      (string)
    @param LambParam    (string)
    @param QParam       (string)
    @param TimeParam    (string)
    @param initFile     (string)
    @param fileTag      (string)   
    @retval ECM      (ElementContainerMatrix)
    """

    if outputData !="QE" and outputData !="HW" and outputData !="TOF" and outputData !="MON":
      print("outputData column : QE or HW or TOF or MON")
      return

    #search_dir="/home/dnaadmin/ana/setup"
    search_dir = os.path.join(mu.UtsusemiEnvGetUserDir(),"ana","setup") #[inamura 230330]
    filepath =os.path.join(search_dir,initFile) 

    useT0ModCorr      = SearchInitParamBool("useT0ModCorr",filepath)
    useMonEff         = SearchInitParamBool("useMonEff",filepath)
    useILambdaCorr    = SearchInitParamBool("useILambdaCorr",filepath)
    useMonNormalCorr  = SearchInitParamBool("useMonNormalCorr",filepath)
    useProtonNormCorr = SearchInitParamBool("useProtonNormCorr",filepath)
    useSolidAngleCorr = SearchInitParamBool("useSolidAngleCorr",filepath)
    useDetEff         = SearchInitParamBool("useDetEff",filepath)
    useAbsoCorr       = SearchInitParamBool("useAbsoCorr",filepath)
    useEffCorr        = SearchInitParamBool("useEffCorr",filepath)
    useFileOutput     = SearchInitParamBool("useFileOutput",filepath)
    filename          = SearchInitParamString("filename",filepath)
    laticetype        = SearchInitParamString("laticetype",filepath)
    sampletype        = SearchInitParamString("sampletype",filepath)
    sampleDataFile    = SearchInitParamString("sampleDataFile",filepath)
    factor            = float(SearchInitParamString("factor",filepath))
    t0_offset         = float(SearchInitParamString("t0_offset",filepath))
    background        = float(SearchInitParamString("background",filepath))
    useFileOutput     = SearchInitParamBool("useFileOutput",filepath)
    #T. Yamada Added [121123]
    UseFastChopper    = SearchInitParamBool("UseFastChopper",filepath)
    #T.Yamada End [121123]


    useEiConv = True

    QParamList = QParam.split(",")
    if len(QParamList)==3:
            startQ = float(QParamList[0])
            endQ = float(QParamList[1])
            deltaQ = float(QParamList[2])
    else:
            startQ = 0.0
            endQ = 3.0
            deltaQ = 0.05
    if outputData != "MON":
        if outputData == "TOF":
           #DAT = BaseComDNA.GetHistogram(runNo,0,-1,-1,-1,-1,-1,100) T. Yamada Comment out [121123]
           DAT = BaseComDNA.GetHistogram(runNo,0,-1,-1,-1,-1,-1,120) #T.Yamada Modified [121123]
           return DAT
        if laticetype == "111":
           #DAT = BaseComDNA.GetHistogramHW(runNo,HwParam,LambParam,t0_offset,useT0ModCorr,TimeParam,L1) T. Yamada Comment out[121123]
           DAT = BaseComDNA.GetHistogramHW(runNo,HwParam,LambParam,t0_offset,useT0ModCorr,TimeParam,UseFastChopper=UseFastChopper) # T. Yamada Modified[121123]
        elif laticetype == "333":
           #DAT = BaseComDNA.GetHistogramHW333(runNo,HwParam,LambParam,t0_offset,useT0ModCorr,TimeParam,L1) T. Yamada Comment out [121123]
            DAT = BaseComDNA.GetHistogramHW333(runNo,HwParam,LambParam,t0_offset,useT0ModCorr,TimeParam,UseFastChopper=UseFastChopper) # T. Yamada Modified[121123]
        else:
           return
        if outputData == "HW":
           print("ttt")
           return DAT
        BaseComDNA.DoMask(DAT, filename)
    #EC = BaseComDNA.GetMonHistogram(runNo,useEiConv,LambParam,t0_offset,background,useT0ModCorr,TimeParam) T. Yamada Comment out [121123]
    EC = BaseComDNA.GetMonHistogram(runNo,useEiConv,LambParam,t0_offset,background,useT0ModCorr,TimeParam,UseFastChopper) #T. Yamada Modified [121123]

    if outputData == "MON":
        return EC

    BaseComDNA.MutiplyConstant(EC,factor)

    if useMonNormalCorr:
        SumEC = sum(EC.PutY())
        BaseComDNA.MutiplyConstant(DAT,1/SumEC/factor)
        print("Monitor Normalize factor * factor = {}".format(SumEC*factor))

    if useProtonNormCorr:
        bc=BaseComDNA.GetRunInfoTime(runNo,TimeParam)
        BaseComDNA.MutiplyConstant(DAT,1/bc/factor)
        print("ProtonCurrent Normalize factor * factor = {}".format(bc*factor))

    if useILambdaCorr:
        ECM = BaseComDNA.ILambdaCorrDNA(DAT, EC, useMonEff)
    else:
        ECM = DAT

    if useSolidAngleCorr:
        ECM2 = BaseComDNA.SolidAngleCorrDNA(ECM, useDetEff, useAbsoCorr,useEffCorr,sampletype,sampleDataFile)
        BaseComDNA.MutiplyConstant(ECM2,1e-6) #T. Yamada Add [121123]
    else:
        ECM2 = ECM
    ECA = BaseComDNA.CreateQEMap(ECM2,startQ,endQ,deltaQ)

    if useFileOutput:
        if (fileTag=="_"):
            BaseComDNA.OutputECA(ECA, "_"+outputData)
            BaseComDNA.OutputECAText(ECA, "_"+outputData)
        else:
            BaseComDNA.OutputECA(ECA, "_"+outputData+"_"+fileTag)
            BaseComDNA.OutputECAText(ECA, "_"+outputData+"_"+fileTag)

    return ECA

#########################################
#T.Yamada [130122]
def GetDataOfDNAElasticScan(runNo=2175,FastChopperUse = True, Analyzer = 111, Time=" ",TempCh = "C2", Temperature=" ", QEReduction=True):
    """
    Get ElasticScan Data
    @param runNo        (int) Run Number
    @FastChopperUse     (bool) Use Fast Chopper
    @Analyzer           (int) Select Si Analyzer 111 or 333
    @Time               (string) time(start), time(end), time(delta)
    @TempCh             (string) temperature Channel A , B, C ,C2, D, or D2 in LS340
    @Temperature        (string) temperature(start), temperature(end), temperature(delta)
    @QEReduction        (bool) Data Reduction 
    @retval EC      (ElementContainerMatrix)
    """
    if Analyzer == 111:
        #---LambdaParam
        LambdaCenter = 6.321
        dLambda = 4.15 #3.0 T.Yamada [130516]
        #---QParam
        Qmin = 0.0
        Qmax = 2.0
        dQ = 0.1
        if FastChopperUse:
            #---HWParam
            Emin = -0.01
            Emax = 0.01
            dE = 0.005
            #---condition file
            #inifile = "GetQEDataOfDNAElasticScan.ini" #the path is "~/ana/setup
            inifile = "GetQEDataOfDNAElasticScanMulth.ini" #the path is "~/ana/setup
        else:
            #---HWParam
            Emin = -0.2
            Emax = 0.05
            dE = 0.05
            #---condition file
            inifile = "GetQEDataOfDNAElasticScanLowResoEMulth.ini" #the path is "~/ana/setup
    elif Analyzer == 333:
        #---LambdaParam
        LambdaCenter = 3.4 # 3 T.Yamada [130516]
        dLambda = 4.16 #3.0 T.Yamada[130516]
        #---QParam
        Qmin = 0.0
        Qmax = 6.0
        dQ = 0.15 #0.1 T.Yamada[130516]

        if FastChopperUse:
            #---HWParam
            Emin = -0.01
            Emax = 0.01
            dE = 0.005
            #---condition file
            inifile = "GetQEDataOfDNAElasticScan.ini" #the path is "~/ana/setup
        else:
            #---HWParam
            Emin = -0.2
            Emax = 0.05
            dE = 0.05
            #---condition file
            inifile = "GetQEDataOfDNAElasticScanLowResoE.ini" #the path is "~/ana/setup

        raise  UserWarning("condition has not been made yet.")
    else:
        raise  UserWarning("input 111 or 333")

    LambdaParam = "%.4f,%.4f" %(LambdaCenter,dLambda)
    HWParam ="%f,%f,%f" %(dE,Emin,Emax)
    HWParam2 ="%f,%f" %(Emin,Emax)
    QParam = "%.3f,%.3f,%.3f" %(Qmin,Qmax,dQ)
    print("HWParam:{} {}".format(HWParam, HWParam2))
    print("LambdaParam:{}".format(LambdaParam))
    print("QParam:{}".format(QParam))

    print("TimeParam: {}".format(Time))
    print("TempCh: {}".format(TempCh))
    print("TempParam: {}".format(Temperature))

#    dataPath = "/usr/local/mlf/DNA/tmp/" T. Yamada[130218]
#    dataPath = "/home/dnaadmin/DNA/tmp/" #T.Yamada[130218]
    dataPath = os.path.join(mu.UtsusemiEnvGetUserDir(),"DNA","tmp") #[inamura 230330]
    ECMbstName = "ECM_%d_ES.bst" %(runNo)
    ESName = "DRRun%dES.txt" % (runNo)
    TIName = "DRRun%dTI.txt" % (runNo)

    ECMbstCheck = os.path.exists(dataPath+ECMbstName)
    ECMbstCheck = os.path.exists(os.path.join(dataPath, ECMbstName))
    print("ECMCheck:{}".format(ECMbstCheck))

    import ElasticScan

    if QEReduction or ECMbstCheck == False :
        print("ECM make start")
        #ECM = ElasticScan.GetQETimeECM(runNo, HWParam, LambdaParam, QParam, Time, inifile) T.Yamada[130304]
        ECM = ElasticScan.GetQETimeECMMulth(runNo, HWParam, LambdaParam, QParam, Time, inifile)
        print("ECM make end")
    ECM = ElasticScan.ReadECM(ECMbstName)
    EC = ElasticScan.ElasticScanTotalIntensity(ECM, HWParam2, QParam, inifile)
    EC2 = ElasticScan.ElasticScanCheckTempNew(EC, TempCh)
    EC4 = ElasticScan.ElasticScanXAxisChangeToTemp(EC, EC2, Temperature)
    ElasticScan.OutputECText(EC, "Run"+str(runNo)+"TItime.txt")
    ElasticScan.OutputECText(EC2,"TItemp.txt")
    ElasticScan.OutputECText(EC4, TIName)
    ECA = ElasticScan.ElasticScanQ2LnI(ECM, HWParam2, QParam, inifile)
    EC1 = ElasticScan.ElasticScanFit(ECA, "p1")
    EC3 = ElasticScan.ElasticScanXAxisChangeToTemp(EC1, EC2, Temperature)
    ElasticScan.OutputECText(EC1, "u2time.txt")
    ElasticScan.OutputECText(EC3, ESName)

    return EC3


#########################################################################

def SearchInitParamBool(paramstring,filepath):
    f=open(filepath)
    lines = f.readlines()
    f.close()

    for line in lines:
        flug1 = re.search(paramstring, line)
        if flug1:
            if re.search("#", line):
                line = line.split("#")[0]
            flug2 = re.search("True",line)
            if flug2:
                print(paramstring,"\t: True")
                return True
            else:
                print(paramstring,"\t: False")
                return False

#########################################################################

def SearchInitParamString(paramstring,filepath):
    f=open(filepath)
    lines = f.readlines()
    f.close()
    result =""
    for line in lines:
        flug1 = re.search(paramstring, line)
        if flug1:
            if re.search("#", line):
                line = line.split("#")[0]
            if re.search("\n", line):
                line = line.split("\n")[0]
            flug2 = re.search(" ", line)
            if flug2:
                linelist =line.split(" ")
                for i in range(len(linelist)):
                    if linelist[i]!="" and linelist[i]!=paramstring:
                         result = linelist[i]
                         print(paramstring,"\t:",result)
    return result


# Dictionary for entry the name of functions
_functions = {
               "CopyData":CopyData,
               "GetDataOfWhite":GetDataOfWhite,
               "GetDataOfMonochroEi":GetDataOfMonochroEi,
               "GetDataOfMonochroEi2":GetDataOfMonochroEi2,
               "ToPowder":ToPowder,
               "GetDataOfDNA":GetDataOfDNA,
               "GetDataOfDNAElasticScan":GetDataOfDNAElasticScan
             }
         



#!/usr/bin/python
# -*- coding: utf-8 -*-

import time
import os
import Manyo as mm
import math

import utsusemi.DNA.ana.Reduction.FunctionBase as FuncBase

# special reserved word for commands history
HISTORY = None

# reserved words for return value in this.
DAT = None
ecs = None
EC = None
EC1 = None
EC2 = None
ret = None
ECA = None

################################################################################################################

def Gaussian(param1=1.0,param2=0.0,param3=0.5,initial_bin=-2.0,final_bin=2.0,delta_bin=0.05,errFact=-1.0):
    """
    @param param1        (float) hight
    @param param2        (float) center
    @param param3        (float) fwhm
    @param initial_bin   (float)
    @param final_bin     (float)
    @param delta_bin     (float)
    @param errFact       (float)
    @retval EC (ElementContainer)
    """
    return FuncBase.Gaussian(param1,param2,param3,initial_bin,final_bin,delta_bin,errFact)

################################################################################################################

def Lorentzian(param1=1.0,param2=0.0,param3=0.5,initial_bin=-2.0,final_bin=2.0,delta_bin=0.05,errFact=-1.0):
    """
    @param param1        (float)
    @param param2        (float)
    @param param3        (float)
    @param initial_bin   (float)
    @param final_bin     (float)
    @param delta_bin     (float)
    @param errFact       (float)
    @retval EC (ElementContainer)
    """
    return FuncBase.Lorentzian(param1,param2,param3,initial_bin,final_bin,delta_bin,errFact)

################################################################################################################

def Function(function="g g",param="",initial_bin=-2.0,final_bin=2.0,delta_bin=0.05,errFact=-1.0):
    """
    @function          (string)
    @param param       (string) 
     "1.0,-0.5,0.3,0.5,1.0,0.4"
    @param initial_bin (float)
    @param final_bin   (float)
    @param delta_bin   (float)
    @param errFact       (float)
    @retval EC (ElementContainer)
    """
    return FuncBase.Function(function,param,initial_bin,final_bin,delta_bin,errFact)

################################################################################################################

def NumpyHammingWindow(ec0=EC):
    """
    @param ec0            (ElementContainer)
    @retval EC           (ElementContainer)
    """
    return FuncBase.NumpyHammingWindow(ec0)

################################################################################################################

def NumpyHanningWindow(ec0=EC):
    """
    @param ec0            (ElementContainer)
    @retval EC           (ElementContainer)
    """
    return FuncBase.NumpyHanningWindow(ec0)

################################################################################################################

def NumpyBlackmanWindow(ec0=EC):
    """
    @param ec0            (ElementContainer)
    @retval EC           (ElementContainer)
    """
    return FuncBase.NumpyBlackmanWindow(ec0)

################################################################################################################

def NumpyBartlettWindow(ec0=EC):
    """
    @param ec0            (ElementContainer)
    @retval EC           (ElementContainer)
    """
    return FuncBase.NumpyBartlettWindow(ec0)

################################################################################################################

def RotationX(ec0=EC,number=100):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval EC            (ElementContainer)
    """
    return FuncBase.RotationX(ec0,number)

################################################################################################################

def HalfRotationX(ec0=EC):
    """
    @param ec0            (ElementContainer)
    @retval EC            (ElementContainer)
    """
    return FuncBase.HalfRotationX(ec0)

################################################################################################################

def AddZeroUpper(ec0=EC,number=100):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval EC            (ElementContainer)
    """
    return FuncBase.AddZeroUpper(ec0,number)

################################################################################################################

def AddZeroLower(ec0=EC,number=100):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval EC            (ElementContainer)
    """
    return FuncBase.AddZeroLower(ec0,number)

################################################################################################################

def AddZero(ec0=EC,number=100):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval EC            (ElementContainer)
    """
    return FuncBase.AddZero(ec0,number)

################################################################################################################

def AddSreiesSamaEC(ec0=EC,number=10):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval EC            (ElementContainer)
    """
    return FuncBase.AddSreiesSamaEC(ec0,number)

################################################################################################################



def ErrorValueMultiplyConstant(ec0=EC,constant=100):
    """
    @param ec0            (ElementContainer)
    @param constant         (int)
    @retval EC            (ElementContainer)
    """
    return FuncBase.ErrorValueMultiplyConstant(ec0,constant)


################################################################################################################

# Dictionary for entry the name of functions
_functions = {
               "Gaussian":Gaussian,
               "Lorentzian":Lorentzian,
               "Function":Function,
               "NumpyHammingWindow":NumpyHammingWindow,
               "NumpyHanningWindow":NumpyHanningWindow,
               "NumpyBlackmanWindow":NumpyBlackmanWindow,
               "NumpyBartlettWindow":NumpyBartlettWindow,
               "AddZeroUpper":AddZeroUpper,
               "AddZeroLower":AddZeroLower,
               "AddZero":AddZero,
               "AddSreiesSamaEC":AddSreiesSamaEC,
               "RotationX":RotationX,
               "HalfRotationX":HalfRotationX,
               "ErrorValueMultiplyConstant":ErrorValueMultiplyConstant
             }
         



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'DetectMapQ.ui'
##
## Created by: Qt User Interface Compiler version 6.3.1
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QAction, QBrush, QColor, QConicalGradient,
    QCursor, QFont, QFontDatabase, QGradient,
    QIcon, QImage, QKeySequence, QLinearGradient,
    QPainter, QPalette, QPixmap, QRadialGradient,
    QTransform)
from PySide6.QtWidgets import (QApplication, QCheckBox, QComboBox, QFrame,
    QGroupBox, QLabel, QLineEdit, QListWidget,
    QListWidgetItem, QMainWindow, QMenu, QMenuBar,
    QPushButton, QSizePolicy, QSlider, QStatusBar,
    QWidget)

class Ui_mapframe(object):
    def setupUi(self, mapframe):
        if not mapframe.objectName():
            mapframe.setObjectName(u"mapframe")
        mapframe.resize(985, 778)
        self.actionOpen = QAction(mapframe)
        self.actionOpen.setObjectName(u"actionOpen")
        self.actionSave = QAction(mapframe)
        self.actionSave.setObjectName(u"actionSave")
        self.actionSave_as = QAction(mapframe)
        self.actionSave_as.setObjectName(u"actionSave_as")
        self.actionPrint = QAction(mapframe)
        self.actionPrint.setObjectName(u"actionPrint")
        self.actionExit = QAction(mapframe)
        self.actionExit.setObjectName(u"actionExit")
        self.actionNew_Plotter = QAction(mapframe)
        self.actionNew_Plotter.setObjectName(u"actionNew_Plotter")
        self.actionLog_Scale = QAction(mapframe)
        self.actionLog_Scale.setObjectName(u"actionLog_Scale")
        self.actionLog_Scale.setCheckable(True)
        self.centralwidget = QWidget(mapframe)
        self.centralwidget.setObjectName(u"centralwidget")
        self.groupBox = QGroupBox(self.centralwidget)
        self.groupBox.setObjectName(u"groupBox")
        self.groupBox.setGeometry(QRect(10, 10, 301, 51))
        self.tof1 = QLineEdit(self.groupBox)
        self.tof1.setObjectName(u"tof1")
        self.tof1.setGeometry(QRect(10, 20, 80, 25))
        self.tof2 = QLineEdit(self.groupBox)
        self.tof2.setObjectName(u"tof2")
        self.tof2.setGeometry(QRect(110, 20, 80, 25))
        self.label = QLabel(self.groupBox)
        self.label.setObjectName(u"label")
        self.label.setGeometry(QRect(100, 20, 16, 25))
        self.btRedraw = QPushButton(self.groupBox)
        self.btRedraw.setObjectName(u"btRedraw")
        self.btRedraw.setGeometry(QRect(200, 20, 80, 30))
        self.groupBox_2 = QGroupBox(self.centralwidget)
        self.groupBox_2.setObjectName(u"groupBox_2")
        self.groupBox_2.setGeometry(QRect(10, 80, 301, 51))
        self.psd0 = QLineEdit(self.groupBox_2)
        self.psd0.setObjectName(u"psd0")
        self.psd0.setGeometry(QRect(80, 20, 80, 25))
        self.bt2dPlot = QPushButton(self.groupBox_2)
        self.bt2dPlot.setObjectName(u"bt2dPlot")
        self.bt2dPlot.setGeometry(QRect(170, 20, 100, 30))
        self.label_2 = QLabel(self.groupBox_2)
        self.label_2.setObjectName(u"label_2")
        self.label_2.setGeometry(QRect(20, 20, 66, 17))
        self.groupBox_3 = QGroupBox(self.centralwidget)
        self.groupBox_3.setObjectName(u"groupBox_3")
        self.groupBox_3.setGeometry(QRect(320, 10, 211, 121))
        self.label_3 = QLabel(self.groupBox_3)
        self.label_3.setObjectName(u"label_3")
        self.label_3.setGeometry(QRect(70, 30, 66, 17))
        self.label_4 = QLabel(self.groupBox_3)
        self.label_4.setObjectName(u"label_4")
        self.label_4.setGeometry(QRect(160, 30, 41, 17))
        self.label_5 = QLabel(self.groupBox_3)
        self.label_5.setObjectName(u"label_5")
        self.label_5.setGeometry(QRect(20, 50, 41, 25))
        self.label_6 = QLabel(self.groupBox_3)
        self.label_6.setObjectName(u"label_6")
        self.label_6.setGeometry(QRect(20, 90, 41, 25))
        self.PSD1 = QLineEdit(self.groupBox_3)
        self.PSD1.setObjectName(u"PSD1")
        self.PSD1.setGeometry(QRect(70, 50, 50, 25))
        self.PSD2 = QLineEdit(self.groupBox_3)
        self.PSD2.setObjectName(u"PSD2")
        self.PSD2.setGeometry(QRect(70, 90, 50, 25))
        self.pixel1 = QLineEdit(self.groupBox_3)
        self.pixel1.setObjectName(u"pixel1")
        self.pixel1.setGeometry(QRect(150, 50, 50, 25))
        self.pixel2 = QLineEdit(self.groupBox_3)
        self.pixel2.setObjectName(u"pixel2")
        self.pixel2.setGeometry(QRect(150, 90, 50, 25))
        self.label_7 = QLabel(self.groupBox_3)
        self.label_7.setObjectName(u"label_7")
        self.label_7.setGeometry(QRect(130, 50, 16, 25))
        self.label_8 = QLabel(self.groupBox_3)
        self.label_8.setObjectName(u"label_8")
        self.label_8.setGeometry(QRect(130, 90, 16, 25))
        self.cbXaxisOfPlot = QComboBox(self.centralwidget)
        self.cbXaxisOfPlot.addItem("")
        self.cbXaxisOfPlot.addItem("")
        self.cbXaxisOfPlot.addItem("")
        self.cbXaxisOfPlot.setObjectName(u"cbXaxisOfPlot")
        self.cbXaxisOfPlot.setGeometry(QRect(560, 10, 100, 27))
        self.btAppend = QPushButton(self.centralwidget)
        self.btAppend.setObjectName(u"btAppend")
        self.btAppend.setGeometry(QRect(560, 40, 150, 27))
        self.btSumm = QPushButton(self.centralwidget)
        self.btSumm.setObjectName(u"btSumm")
        self.btSumm.setGeometry(QRect(560, 70, 150, 27))
        self.btNewPlot = QPushButton(self.centralwidget)
        self.btNewPlot.setObjectName(u"btNewPlot")
        self.btNewPlot.setGeometry(QRect(560, 100, 150, 27))
        self.label_9 = QLabel(self.centralwidget)
        self.label_9.setObjectName(u"label_9")
        self.label_9.setGeometry(QRect(720, 10, 66, 17))
        self.ckconv = QCheckBox(self.centralwidget)
        self.ckconv.setObjectName(u"ckconv")
        self.ckconv.setGeometry(QRect(810, 10, 151, 22))
        self.plotList = QListWidget(self.centralwidget)
        self.plotList.setObjectName(u"plotList")
        self.plotList.setGeometry(QRect(720, 30, 200, 115))
        self.slider = QSlider(self.centralwidget)
        self.slider.setObjectName(u"slider")
        self.slider.setGeometry(QRect(0, 230, 30, 350))
        self.slider.setValue(99)
        self.slider.setOrientation(Qt.Vertical)
        self.slider.setInvertedAppearance(False)
        self.mapPanel = QWidget(self.centralwidget)
        self.mapPanel.setObjectName(u"mapPanel")
        self.mapPanel.setGeometry(QRect(30, 160, 950, 500))
        self.groupBox_4 = QGroupBox(self.centralwidget)
        self.groupBox_4.setObjectName(u"groupBox_4")
        self.groupBox_4.setGeometry(QRect(30, 670, 401, 51))
        self.ymin = QLineEdit(self.groupBox_4)
        self.ymin.setObjectName(u"ymin")
        self.ymin.setGeometry(QRect(20, 20, 100, 25))
        self.ymax = QLineEdit(self.groupBox_4)
        self.ymax.setObjectName(u"ymax")
        self.ymax.setGeometry(QRect(130, 20, 100, 25))
        self.label_10 = QLabel(self.groupBox_4)
        self.label_10.setObjectName(u"label_10")
        self.label_10.setGeometry(QRect(120, 20, 16, 25))
        self.btIntSet = QPushButton(self.groupBox_4)
        self.btIntSet.setObjectName(u"btIntSet")
        self.btIntSet.setGeometry(QRect(240, 20, 80, 30))
        self.btIntClear = QPushButton(self.groupBox_4)
        self.btIntClear.setObjectName(u"btIntClear")
        self.btIntClear.setGeometry(QRect(340, 20, 50, 30))
        self.infotxt = QLabel(self.centralwidget)
        self.infotxt.setObjectName(u"infotxt")
        self.infotxt.setGeometry(QRect(450, 670, 500, 55))
        self.infotxt.setAlignment(Qt.AlignLeading|Qt.AlignLeft|Qt.AlignTop)
        self.line = QFrame(self.centralwidget)
        self.line.setObjectName(u"line")
        self.line.setGeometry(QRect(0, 140, 981, 16))
        self.line.setFrameShape(QFrame.HLine)
        self.line.setFrameShadow(QFrame.Sunken)
        mapframe.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(mapframe)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 985, 28))
        self.menuFile = QMenu(self.menubar)
        self.menuFile.setObjectName(u"menuFile")
        self.menuDisplay = QMenu(self.menubar)
        self.menuDisplay.setObjectName(u"menuDisplay")
        mapframe.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(mapframe)
        self.statusbar.setObjectName(u"statusbar")
        mapframe.setStatusBar(self.statusbar)

        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuDisplay.menuAction())
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionSave)
        self.menuFile.addAction(self.actionSave_as)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionPrint)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuDisplay.addAction(self.actionNew_Plotter)
        self.menuDisplay.addAction(self.actionLog_Scale)

        self.retranslateUi(mapframe)

        QMetaObject.connectSlotsByName(mapframe)
    # setupUi

    def retranslateUi(self, mapframe):
        mapframe.setWindowTitle(QCoreApplication.translate("mapframe", u"Detect Map", None))
        self.actionOpen.setText(QCoreApplication.translate("mapframe", u"Open ...", None))
        self.actionSave.setText(QCoreApplication.translate("mapframe", u"Save", None))
        self.actionSave_as.setText(QCoreApplication.translate("mapframe", u"Save as ...", None))
        self.actionPrint.setText(QCoreApplication.translate("mapframe", u"Print ...", None))
        self.actionExit.setText(QCoreApplication.translate("mapframe", u"Exit", None))
        self.actionNew_Plotter.setText(QCoreApplication.translate("mapframe", u"New Plotter ...", None))
        self.actionLog_Scale.setText(QCoreApplication.translate("mapframe", u"Log Scale", None))
        self.groupBox.setTitle(QCoreApplication.translate("mapframe", u"X-axis Range of Pixel", None))
        self.label.setText(QCoreApplication.translate("mapframe", u"-", None))
        self.btRedraw.setText(QCoreApplication.translate("mapframe", u"Redraw", None))
        self.groupBox_2.setTitle(QCoreApplication.translate("mapframe", u"2D Plot of Detector", None))
        self.bt2dPlot.setText(QCoreApplication.translate("mapframe", u"2D Plot", None))
        self.label_2.setText(QCoreApplication.translate("mapframe", u"DetNo. :", None))
        self.groupBox_3.setTitle(QCoreApplication.translate("mapframe", u"Detector-Pixel Range", None))
        self.label_3.setText(QCoreApplication.translate("mapframe", u"Detector", None))
        self.label_4.setText(QCoreApplication.translate("mapframe", u"Pixel", None))
        self.label_5.setText(QCoreApplication.translate("mapframe", u"From", None))
        self.label_6.setText(QCoreApplication.translate("mapframe", u"To", None))
        self.label_7.setText(QCoreApplication.translate("mapframe", u"-", None))
        self.label_8.setText(QCoreApplication.translate("mapframe", u"-", None))
        self.cbXaxisOfPlot.setItemText(0, QCoreApplication.translate("mapframe", u"TOF", None))
        self.cbXaxisOfPlot.setItemText(1, QCoreApplication.translate("mapframe", u"Detector", None))
        self.cbXaxisOfPlot.setItemText(2, QCoreApplication.translate("mapframe", u"Pixel", None))

        self.btAppend.setText(QCoreApplication.translate("mapframe", u"Append >>", None))
        self.btSumm.setText(QCoreApplication.translate("mapframe", u"Append Sum >>", None))
        self.btNewPlot.setText(QCoreApplication.translate("mapframe", u"New Plotter", None))
        self.label_9.setText(QCoreApplication.translate("mapframe", u"Plotters", None))
        self.ckconv.setText(QCoreApplication.translate("mapframe", u"Convert toEnergy", None))
        self.groupBox_4.setTitle(QCoreApplication.translate("mapframe", u"Intensity Range", None))
        self.label_10.setText(QCoreApplication.translate("mapframe", u"-", None))
        self.btIntSet.setText(QCoreApplication.translate("mapframe", u"Apply", None))
        self.btIntClear.setText(QCoreApplication.translate("mapframe", u"Clear", None))
        self.infotxt.setText(QCoreApplication.translate("mapframe", u"Det-ID", None))
        self.menuFile.setTitle(QCoreApplication.translate("mapframe", u"File", None))
        self.menuDisplay.setTitle(QCoreApplication.translate("mapframe", u"Display", None))
    # retranslateUi




# -*- coding: utf-8 -*-

import sys
import string
import math

import unittest


class TestManyoFunctions( unittest.TestCase ):

    def test_HistOperations( self ):

        import HistOperations
        ECA = HistOperations.Result
        HistOperations.ElementContainerArrayToText( ECA, "HistOperations.txt" )

        self.assertTrue( HistOperations.ModTest.CompareTextFile(
            "test20160425_r268.txt", "HistOperations.txt" ) )

    def test_HistOperationsHeavy( self ):

        import HistOperationsHeavy
        ECA = HistOperationsHeavy.eca
        HistOperationsHeavy.HistOperations.ElementContainerArrayToText(
            ECA, "HistOperationsHeavy.txt" )

        self.assertTrue( HistOperationsHeavy.HistOperations.ModTest.CompareTextFile(
            "test20160425heavy_r268.txt", "HistOperationsHeavy.txt" ) )


# unittestの継承クラス すべてを実行する
if __name__ == '__main__':
    unittest.main()






# -*- coding: utf-8 -*-

import sys
import string
import math

import Manyo.core
import ModuleTest as ModTest

ec0 = ModTest.ec0

Mout = Manyo.WriteSerializationFileBinary( "test.bin" )
Mout.Save( ec0 )
del( Mout )

Min = Manyo.ReadSerializationFileBinary( "test.bin" )
e1r = Manyo.ElementContainer()
Min.Load( e1r )
del( Min )


#module.PrintElementContainer( e1r )



# -*- coding: utf-8 -*-

import sys
import string
import math

FileName = sys.argv[1]
# 引数として 年月日を8桁で入力のこと

import moduleAveraging
moduleAveraging.ModTest.ElementContainerToText(
    moduleAveraging.e2, "Averaging2_" + FileName + ".txt" )
moduleAveraging.ModTest.ElementContainerToText(
    moduleAveraging.e3, "Averaging3_" + FileName + ".txt" )

import moduleBinning
moduleBinning.ModTest.ElementContainerToText(
    moduleBinning.e2, "Binning2_" + FileName + ".txt" )
moduleBinning.ModTest.ElementContainerToText(
    moduleBinning.e3, "Binning3_" + FileName + ".txt" )


import moduleBoostSerial
moduleBoostSerial.ModTest.ElementContainerToText(
    moduleBoostSerial.e1r, "BoostSerial_" + FileName + ".txt" )

import moduleNeXus
moduleNeXus.ModTest.ElementContainerToText(
    moduleNeXus.e2, "NeXus_" + FileName + ".txt" )


import moduleArithmeticOperations

moduleArithmeticOperations.ModTest.ElementContainerToText(
    moduleArithmeticOperations.eca, "ArithAdd_" + FileName + ".txt" )

moduleArithmeticOperations.ModTest.ElementContainerToText(
    moduleArithmeticOperations.ecs, "ArithSub_" + FileName + ".txt" )

moduleArithmeticOperations.ModTest.ElementContainerToText(
    moduleArithmeticOperations.ecm, "ArithMul_" + FileName + ".txt" )

moduleArithmeticOperations.ModTest.ElementContainerToText(
    moduleArithmeticOperations.ecd, "ArithDiv_" + FileName + ".txt" )

moduleArithmeticOperations.ModTest.ElementContainerToText(
    moduleArithmeticOperations.e2, "Arith2_" + FileName + ".txt" )





# -*- coding: utf-8 -*-
import Manyo as m
import Manyo.MLF as mlf
import math

xList = [] # ヒストグラムのBinの定義
for i in range( 20 ):
    xList.append( float( i ) )

yList = [] # intensityが入る
eList = [] # intensityのエラーを入れる

ge = m.GaussianEventData( 50.0, 30.0, 1, 100 )
for i in range( len( xList ) -1 ):
    intensity = float( ge.Next() ) # intensityは乱数を入れる
    err       = math.sqrt( intensity )
    yList.append( intensity )
    eList.append( err )

e1 = m.ElementContainer()
# データコンテナを定義する

e1.Add( "x", xList ) # キー:x で登録する
e1.Add( "y", yList ) # キー:y で登録する
e1.Add( "e", eList ) # キー:e で登録する
e1.SetKeys( "x", "y", "e" ) # ヒストグラムとして認識させる
e1.Dump() # 標準出力に送る

import GnuPlotFormat
# Gnuplotのファイル形式で出してみる
# GnuPlotFormat.pyをカレントディレクトリにコピーしておくこと
GnuPlotFormat.DumpToFile( e1, "TestData.txt" )
GnuPlotFormat.DumpToFileErr( e1, "TestDataErr.txt" )



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'SliceViewerMain.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(800, 600)
        self.data_load_view_action = QAction(MainWindow)
        self.data_load_view_action.setObjectName(u"data_load_view_action")
        self.data_load_view_action.setCheckable(False)
        self.data_load_view_action.setChecked(False)
        icon = QIcon()
        icon.addFile(u"icons/SliceViewerMain/OpenFile.png", QSize(), QIcon.Normal, QIcon.Off)
        self.data_load_view_action.setIcon(icon)
        self.data_load_view_action.setIconVisibleInMenu(True)
        self.basic_slice_view_action = QAction(MainWindow)
        self.basic_slice_view_action.setObjectName(u"basic_slice_view_action")
        self.basic_slice_view_action.setCheckable(True)
        self.basic_slice_view_action.setChecked(True)
        icon1 = QIcon()
        icon1.addFile(u"icons/SliceViewerMain/3d_effect.png", QSize(), QIcon.Normal, QIcon.Off)
        self.basic_slice_view_action.setIcon(icon1)
        self.basic_slice_slider_view_action = QAction(MainWindow)
        self.basic_slice_slider_view_action.setObjectName(u"basic_slice_slider_view_action")
        self.basic_slice_slider_view_action.setCheckable(True)
        self.basic_slice_slider_view_action.setChecked(False)
        icon2 = QIcon()
        icon2.addFile(u"icons/SliceViewerMain/hslider.png", QSize(), QIcon.Normal, QIcon.Off)
        self.basic_slice_slider_view_action.setIcon(icon2)
        self.free_slice_view_action = QAction(MainWindow)
        self.free_slice_view_action.setObjectName(u"free_slice_view_action")
        self.free_slice_view_action.setCheckable(True)
        self.free_slice_view_action.setChecked(False)
        icon3 = QIcon()
        icon3.addFile(u"icons/SliceViewerMain/3d_free.png", QSize(), QIcon.Normal, QIcon.Off)
        self.free_slice_view_action.setIcon(icon3)
        self.view_setting_view_action = QAction(MainWindow)
        self.view_setting_view_action.setObjectName(u"view_setting_view_action")
        self.view_setting_view_action.setCheckable(True)
        self.view_setting_view_action.setChecked(False)
        icon4 = QIcon()
        icon4.addFile(u"icons/SliceViewerMain/samsung__04.png", QSize(), QIcon.Normal, QIcon.Off)
        self.view_setting_view_action.setIcon(icon4)
        self.color_bar_view_action = QAction(MainWindow)
        self.color_bar_view_action.setObjectName(u"color_bar_view_action")
        self.color_bar_view_action.setCheckable(True)
        self.color_bar_view_action.setChecked(True)
        icon5 = QIcon()
        icon5.addFile(u"icons/SliceViewerMain/color-table.png", QSize(), QIcon.Normal, QIcon.Off)
        self.color_bar_view_action.setIcon(icon5)
        self.color_bar_setting_view_action = QAction(MainWindow)
        self.color_bar_setting_view_action.setObjectName(u"color_bar_setting_view_action")
        self.color_bar_setting_view_action.setCheckable(True)
        self.color_bar_setting_view_action.setChecked(False)
        icon6 = QIcon()
        icon6.addFile(u"icons/SliceViewerMain/color.png", QSize(), QIcon.Normal, QIcon.Off)
        self.color_bar_setting_view_action.setIcon(icon6)
        self.label_setting_view_action = QAction(MainWindow)
        self.label_setting_view_action.setObjectName(u"label_setting_view_action")
        self.label_setting_view_action.setCheckable(True)
        self.label_setting_view_action.setChecked(False)
        icon7 = QIcon()
        icon7.addFile(u"icons/SliceViewerMain/str.png", QSize(), QIcon.Normal, QIcon.Off)
        self.label_setting_view_action.setIcon(icon7)
        self.zoom_best_fit_action = QAction(MainWindow)
        self.zoom_best_fit_action.setObjectName(u"zoom_best_fit_action")
        self.zoom_best_fit_action.setCheckable(False)
        self.zoom_best_fit_action.setChecked(False)
        icon8 = QIcon()
        icon8.addFile(u"icons/SliceViewerMain/zoom-best-fit.png", QSize(), QIcon.Normal, QIcon.Off)
        self.zoom_best_fit_action.setIcon(icon8)
        self.zoom_best_fit_action.setIconVisibleInMenu(True)
        self.view_direction_to_plus_x_action = QAction(MainWindow)
        self.view_direction_to_plus_x_action.setObjectName(u"view_direction_to_plus_x_action")
        self.view_direction_to_plus_x_action.setChecked(False)
        icon9 = QIcon()
        icon9.addFile(u"icons/SliceViewerMain/view_nyz.png", QSize(), QIcon.Normal, QIcon.Off)
        self.view_direction_to_plus_x_action.setIcon(icon9)
        self.view_direction_to_plus_x_action.setIconVisibleInMenu(True)
        self.view_direction_to_minus_x_action = QAction(MainWindow)
        self.view_direction_to_minus_x_action.setObjectName(u"view_direction_to_minus_x_action")
        self.view_direction_to_minus_x_action.setChecked(False)
        icon10 = QIcon()
        icon10.addFile(u"icons/SliceViewerMain/view_yz.png", QSize(), QIcon.Normal, QIcon.Off)
        self.view_direction_to_minus_x_action.setIcon(icon10)
        self.view_direction_to_minus_x_action.setIconVisibleInMenu(True)
        self.view_direction_to_plus_y_action = QAction(MainWindow)
        self.view_direction_to_plus_y_action.setObjectName(u"view_direction_to_plus_y_action")
        self.view_direction_to_plus_y_action.setChecked(False)
        icon11 = QIcon()
        icon11.addFile(u"icons/SliceViewerMain/view_xz.png", QSize(), QIcon.Normal, QIcon.Off)
        self.view_direction_to_plus_y_action.setIcon(icon11)
        self.view_direction_to_plus_y_action.setIconVisibleInMenu(True)
        self.view_direction_to_minus_y_action = QAction(MainWindow)
        self.view_direction_to_minus_y_action.setObjectName(u"view_direction_to_minus_y_action")
        self.view_direction_to_minus_y_action.setChecked(False)
        icon12 = QIcon()
        icon12.addFile(u"icons/SliceViewerMain/view_nxz.png", QSize(), QIcon.Normal, QIcon.Off)
        self.view_direction_to_minus_y_action.setIcon(icon12)
        self.view_direction_to_minus_y_action.setIconVisibleInMenu(True)
        self.view_direction_to_plus_z_action = QAction(MainWindow)
        self.view_direction_to_plus_z_action.setObjectName(u"view_direction_to_plus_z_action")
        self.view_direction_to_plus_z_action.setChecked(False)
        icon13 = QIcon()
        icon13.addFile(u"icons/SliceViewerMain/view_nxy.png", QSize(), QIcon.Normal, QIcon.Off)
        self.view_direction_to_plus_z_action.setIcon(icon13)
        self.view_direction_to_plus_z_action.setIconVisibleInMenu(True)
        self.view_direction_to_minus_z_action = QAction(MainWindow)
        self.view_direction_to_minus_z_action.setObjectName(u"view_direction_to_minus_z_action")
        self.view_direction_to_minus_z_action.setChecked(False)
        icon14 = QIcon()
        icon14.addFile(u"icons/SliceViewerMain/view_xy.png", QSize(), QIcon.Normal, QIcon.Off)
        self.view_direction_to_minus_z_action.setIcon(icon14)
        self.view_direction_to_minus_z_action.setIconVisibleInMenu(True)
        self.data_info_view_action = QAction(MainWindow)
        self.data_info_view_action.setObjectName(u"data_info_view_action")
        self.data_info_view_action.setCheckable(True)
        self.data_info_view_action.setChecked(False)
        icon15 = QIcon()
        icon15.addFile(u"icons/SliceViewerMain/Information.png", QSize(), QIcon.Normal, QIcon.Off)
        self.data_info_view_action.setIcon(icon15)
        self.data_info_view_action.setIconVisibleInMenu(True)
        self.axis_grid_view_action = QAction(MainWindow)
        self.axis_grid_view_action.setObjectName(u"axis_grid_view_action")
        self.axis_grid_view_action.setCheckable(True)
        self.axis_grid_view_action.setChecked(False)
        icon16 = QIcon()
        icon16.addFile(u"icons/SliceViewerMain/axis.png", QSize(), QIcon.Normal, QIcon.Off)
        self.axis_grid_view_action.setIcon(icon16)
        self.axis_grid_view_action.setIconVisibleInMenu(True)
        self.increase_vertical_size_action = QAction(MainWindow)
        self.increase_vertical_size_action.setObjectName(u"increase_vertical_size_action")
        self.increase_vertical_size_action.setCheckable(False)
        self.increase_vertical_size_action.setChecked(False)
        icon17 = QIcon()
        icon17.addFile(u"icons/SliceViewerMain/IncVertSize.png", QSize(), QIcon.Normal, QIcon.Off)
        self.increase_vertical_size_action.setIcon(icon17)
        self.increase_vertical_size_action.setIconVisibleInMenu(True)
        self.decrease_vertical_size_action = QAction(MainWindow)
        self.decrease_vertical_size_action.setObjectName(u"decrease_vertical_size_action")
        self.decrease_vertical_size_action.setCheckable(False)
        self.decrease_vertical_size_action.setChecked(False)
        icon18 = QIcon()
        icon18.addFile(u"icons/SliceViewerMain/DecVertSize.png", QSize(), QIcon.Normal, QIcon.Off)
        self.decrease_vertical_size_action.setIcon(icon18)
        self.decrease_vertical_size_action.setIconVisibleInMenu(True)
        self.increase_horizontal_size_action = QAction(MainWindow)
        self.increase_horizontal_size_action.setObjectName(u"increase_horizontal_size_action")
        self.increase_horizontal_size_action.setCheckable(False)
        self.increase_horizontal_size_action.setChecked(False)
        icon19 = QIcon()
        icon19.addFile(u"icons/SliceViewerMain/IncHoriSize.png", QSize(), QIcon.Normal, QIcon.Off)
        self.increase_horizontal_size_action.setIcon(icon19)
        self.increase_horizontal_size_action.setIconVisibleInMenu(True)
        self.decrease_horizontal_size_action = QAction(MainWindow)
        self.decrease_horizontal_size_action.setObjectName(u"decrease_horizontal_size_action")
        self.decrease_horizontal_size_action.setCheckable(False)
        self.decrease_horizontal_size_action.setChecked(False)
        icon20 = QIcon()
        icon20.addFile(u"icons/SliceViewerMain/DecHoriSize.png", QSize(), QIcon.Normal, QIcon.Off)
        self.decrease_horizontal_size_action.setIcon(icon20)
        self.decrease_horizontal_size_action.setIconVisibleInMenu(True)
        self.view_screenshot_action = QAction(MainWindow)
        self.view_screenshot_action.setObjectName(u"view_screenshot_action")
        self.view_screenshot_action.setChecked(False)
        icon21 = QIcon()
        icon21.addFile(u"icons/SliceViewerMain/Camera.png", QSize(), QIcon.Normal, QIcon.Off)
        self.view_screenshot_action.setIcon(icon21)
        self.translucent_action = QAction(MainWindow)
        self.translucent_action.setObjectName(u"translucent_action")
        self.translucent_action.setCheckable(True)
        self.translucent_action.setChecked(True)
        icon22 = QIcon()
        icon22.addFile(u"icons/SliceViewerMain/Transparency.png", QSize(), QIcon.Normal, QIcon.Off)
        self.translucent_action.setIcon(icon22)
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.gridLayout = QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName(u"gridLayout")
        self.topLayout = QHBoxLayout()
        self.topLayout.setObjectName(u"topLayout")
        self.parameterLayout = QVBoxLayout()
        self.parameterLayout.setObjectName(u"parameterLayout")

        self.topLayout.addLayout(self.parameterLayout)

        self.mainViewLayout = QVBoxLayout()
        self.mainViewLayout.setObjectName(u"mainViewLayout")

        self.topLayout.addLayout(self.mainViewLayout)

        self.colorBarLayout = QHBoxLayout()
        self.colorBarLayout.setObjectName(u"colorBarLayout")

        self.topLayout.addLayout(self.colorBarLayout)


        self.gridLayout.addLayout(self.topLayout, 0, 0, 1, 1)

        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.menuBar = QMenuBar(MainWindow)
        self.menuBar.setObjectName(u"menuBar")
        self.menuBar.setGeometry(QRect(0, 0, 800, 20))
        self.menu = QMenu(self.menuBar)
        self.menu.setObjectName(u"menu")
        self.menu_2 = QMenu(self.menuBar)
        self.menu_2.setObjectName(u"menu_2")
        MainWindow.setMenuBar(self.menuBar)
        self.toolBar = QToolBar(MainWindow)
        self.toolBar.setObjectName(u"toolBar")
        MainWindow.addToolBar(Qt.TopToolBarArea, self.toolBar)

        self.menuBar.addAction(self.menu.menuAction())
        self.menuBar.addAction(self.menu_2.menuAction())
        self.menu.addAction(self.data_load_view_action)
        self.menu.addAction(self.data_info_view_action)
        self.menu_2.addSeparator()
        self.menu_2.addAction(self.basic_slice_view_action)
        self.menu_2.addAction(self.free_slice_view_action)
        self.menu_2.addSeparator()
        self.menu_2.addAction(self.color_bar_view_action)
        self.menu_2.addAction(self.axis_grid_view_action)
        self.menu_2.addAction(self.view_setting_view_action)
        self.menu_2.addAction(self.label_setting_view_action)
        self.menu_2.addSeparator()
        self.menu_2.addAction(self.view_screenshot_action)
        self.menu_2.addAction(self.translucent_action)
        self.menu_2.addSeparator()
        self.menu_2.addAction(self.zoom_best_fit_action)
        self.menu_2.addAction(self.view_direction_to_plus_x_action)
        self.menu_2.addAction(self.view_direction_to_minus_x_action)
        self.menu_2.addAction(self.view_direction_to_plus_y_action)
        self.menu_2.addAction(self.view_direction_to_minus_y_action)
        self.menu_2.addAction(self.view_direction_to_plus_z_action)
        self.menu_2.addAction(self.view_direction_to_minus_z_action)
        self.menu_2.addSeparator()
        self.menu_2.addAction(self.increase_vertical_size_action)
        self.menu_2.addAction(self.decrease_vertical_size_action)
        self.menu_2.addAction(self.increase_horizontal_size_action)
        self.menu_2.addAction(self.decrease_horizontal_size_action)
        self.toolBar.addAction(self.data_load_view_action)
        self.toolBar.addAction(self.data_info_view_action)
        self.toolBar.addAction(self.basic_slice_view_action)
        self.toolBar.addAction(self.free_slice_view_action)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.color_bar_view_action)
        self.toolBar.addAction(self.axis_grid_view_action)
        self.toolBar.addAction(self.view_setting_view_action)
        self.toolBar.addAction(self.label_setting_view_action)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.view_screenshot_action)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.translucent_action)
        self.toolBar.addAction(self.zoom_best_fit_action)
        self.toolBar.addAction(self.view_direction_to_plus_x_action)
        self.toolBar.addAction(self.view_direction_to_minus_x_action)
        self.toolBar.addAction(self.view_direction_to_plus_y_action)
        self.toolBar.addAction(self.view_direction_to_minus_y_action)
        self.toolBar.addAction(self.view_direction_to_plus_z_action)
        self.toolBar.addAction(self.view_direction_to_minus_z_action)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.increase_vertical_size_action)
        self.toolBar.addAction(self.decrease_vertical_size_action)
        self.toolBar.addAction(self.increase_horizontal_size_action)
        self.toolBar.addAction(self.decrease_horizontal_size_action)
        self.toolBar.addSeparator()

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"MainWindow", None))
        self.data_load_view_action.setText(QCoreApplication.translate("MainWindow", u"Load Data", None))
        self.basic_slice_view_action.setText(QCoreApplication.translate("MainWindow", u"Basic Slice", None))
        self.basic_slice_slider_view_action.setText(QCoreApplication.translate("MainWindow", u"Slider For Basic Slice", None))
        self.free_slice_view_action.setText(QCoreApplication.translate("MainWindow", u"Free Slice", None))
        self.view_setting_view_action.setText(QCoreApplication.translate("MainWindow", u"View Settings", None))
        self.color_bar_view_action.setText(QCoreApplication.translate("MainWindow", u"Color Bar", None))
        self.color_bar_setting_view_action.setText(QCoreApplication.translate("MainWindow", u"Color Bar Settings", None))
#if QT_CONFIG(tooltip)
        self.color_bar_setting_view_action.setToolTip(QCoreApplication.translate("MainWindow", u"Color Bar Settings", None))
#endif // QT_CONFIG(tooltip)
        self.label_setting_view_action.setText(QCoreApplication.translate("MainWindow", u"label Settings", None))
#if QT_CONFIG(tooltip)
        self.label_setting_view_action.setToolTip(QCoreApplication.translate("MainWindow", u"Label Settings", None))
#endif // QT_CONFIG(tooltip)
        self.zoom_best_fit_action.setText(QCoreApplication.translate("MainWindow", u"Zoom best fit", None))
#if QT_CONFIG(tooltip)
        self.zoom_best_fit_action.setToolTip(QCoreApplication.translate("MainWindow", u"Zoom best fit", None))
#endif // QT_CONFIG(tooltip)
        self.view_direction_to_plus_x_action.setText(QCoreApplication.translate("MainWindow", u"Set View direction to +X", None))
#if QT_CONFIG(tooltip)
        self.view_direction_to_plus_x_action.setToolTip(QCoreApplication.translate("MainWindow", u"View direction to +X", None))
#endif // QT_CONFIG(tooltip)
        self.view_direction_to_minus_x_action.setText(QCoreApplication.translate("MainWindow", u"Set View direction to -X", None))
#if QT_CONFIG(tooltip)
        self.view_direction_to_minus_x_action.setToolTip(QCoreApplication.translate("MainWindow", u"View direction to -X", None))
#endif // QT_CONFIG(tooltip)
        self.view_direction_to_plus_y_action.setText(QCoreApplication.translate("MainWindow", u"Set View direction to +Y", None))
#if QT_CONFIG(tooltip)
        self.view_direction_to_plus_y_action.setToolTip(QCoreApplication.translate("MainWindow", u"View direction to +Y", None))
#endif // QT_CONFIG(tooltip)
        self.view_direction_to_minus_y_action.setText(QCoreApplication.translate("MainWindow", u"Set View direction to -Y", None))
#if QT_CONFIG(tooltip)
        self.view_direction_to_minus_y_action.setToolTip(QCoreApplication.translate("MainWindow", u"View direction to -X", None))
#endif // QT_CONFIG(tooltip)
        self.view_direction_to_plus_z_action.setText(QCoreApplication.translate("MainWindow", u"Set View direction to +Z", None))
#if QT_CONFIG(tooltip)
        self.view_direction_to_plus_z_action.setToolTip(QCoreApplication.translate("MainWindow", u"View direction to +Z", None))
#endif // QT_CONFIG(tooltip)
        self.view_direction_to_minus_z_action.setText(QCoreApplication.translate("MainWindow", u"Set View direction to -Z", None))
#if QT_CONFIG(tooltip)
        self.view_direction_to_minus_z_action.setToolTip(QCoreApplication.translate("MainWindow", u"View direction to -Z", None))
#endif // QT_CONFIG(tooltip)
        self.data_info_view_action.setText(QCoreApplication.translate("MainWindow", u"Data Information", None))
#if QT_CONFIG(tooltip)
        self.data_info_view_action.setToolTip(QCoreApplication.translate("MainWindow", u"Data Information", None))
#endif // QT_CONFIG(tooltip)
        self.axis_grid_view_action.setText(QCoreApplication.translate("MainWindow", u"Axis/Grid", None))
#if QT_CONFIG(tooltip)
        self.axis_grid_view_action.setToolTip(QCoreApplication.translate("MainWindow", u"Axis/Grid", None))
#endif // QT_CONFIG(tooltip)
        self.increase_vertical_size_action.setText(QCoreApplication.translate("MainWindow", u"Increase Vertical Size ", None))
#if QT_CONFIG(tooltip)
        self.increase_vertical_size_action.setToolTip(QCoreApplication.translate("MainWindow", u"Increase Vertical Size", None))
#endif // QT_CONFIG(tooltip)
        self.decrease_vertical_size_action.setText(QCoreApplication.translate("MainWindow", u"Decrease Vertical Size", None))
#if QT_CONFIG(tooltip)
        self.decrease_vertical_size_action.setToolTip(QCoreApplication.translate("MainWindow", u"Decrease Vertical Size", None))
#endif // QT_CONFIG(tooltip)
        self.increase_horizontal_size_action.setText(QCoreApplication.translate("MainWindow", u"Increase Horizontal Size", None))
#if QT_CONFIG(tooltip)
        self.increase_horizontal_size_action.setToolTip(QCoreApplication.translate("MainWindow", u"Decrease Horizontal Size", None))
#endif // QT_CONFIG(tooltip)
        self.decrease_horizontal_size_action.setText(QCoreApplication.translate("MainWindow", u"Decrease Horizontal Size", None))
#if QT_CONFIG(tooltip)
        self.decrease_horizontal_size_action.setToolTip(QCoreApplication.translate("MainWindow", u"Decrease Horizontal Size", None))
#endif // QT_CONFIG(tooltip)
        self.view_screenshot_action.setText(QCoreApplication.translate("MainWindow", u"Screenshot", None))
#if QT_CONFIG(tooltip)
        self.view_screenshot_action.setToolTip(QCoreApplication.translate("MainWindow", u"Screenshot", None))
#endif // QT_CONFIG(tooltip)
        self.translucent_action.setText(QCoreApplication.translate("MainWindow", u"Translucent", None))
#if QT_CONFIG(tooltip)
        self.translucent_action.setToolTip(QCoreApplication.translate("MainWindow", u"translucent", None))
#endif // QT_CONFIG(tooltip)
        self.menu.setTitle(QCoreApplication.translate("MainWindow", u"File", None))
        self.menu_2.setTitle(QCoreApplication.translate("MainWindow", u"View", None))
        self.toolBar.setWindowTitle(QCoreApplication.translate("MainWindow", u"toolBar", None))
    # retranslateUi




#!/usr/bin/python

import Manyo
import PeakData

peak0=PeakData.Peak(PeakData.SHOLDER_I, -2.5,  50000.0,   4.5, -7.5, -2.5);
peak1=PeakData.Peak(PeakData.PEAK     ,  0.0, 100000.0,   2.5, -2.5,  2.5);
peak2=PeakData.Peak(PeakData.SHOLDER_D,  2.5,  50000.0,   4.5,  2.5,  7.5);
PeakData.Peak.title()
peak0.dump()
peak1.dump()
peak2.dump()

pc = PeakData.PeakData()
pc.add(peak0)
pc.add(peak1)
pc.add(peak2)

v = pc.toVector()
print isinstance(v, Manyo.VecDouble)
print v
print "size=", v.size()
for i in range(v.size()):
    print "v[", i, "]=", v[i]
print ""

v = pc.toFullVector()
print "size=", v.size()
for i in range(v.size()):
    print "v[", i, "]=", v[i]
print ""

pc.Dump()

#print "size of short array =", pc.sizeOfArray()
#v = pc.toArray()
#for i in range( pc.sizeOfArray() ):
#    print "v[", i, "]=", v[i]
#print ""

#print "size of gsl short array =", pc.sizeOfGslArray()
#v = pc.toGslVector()
#for i in range( pc.sizeOfGslVector() ):
#    print "v[", i, "]=", v[i]
#print ""

